Attribute VB_Name = "ModDX7"
'ModDX7 - by Simon Price
'a module of simple funtions to make DirectX 7 easier to program
Option Explicit

Public DirectX As New DirectX7
Public DX_Draw As DirectDraw7

Public DestRect As RECT
Public SrcRect As RECT

Dim InExMode As Boolean







Public Sub SetDisplayMode(width As Long, height As Long, Colors As Long)
    'set's the display mode to the required size and colors
     DX_Draw.SetDisplayMode width, height, Colors, 0, DDSDM_DEFAULT
End Sub

Public Sub RestoreDisplayMode()
    'puts the screen back to normal
     DX_Draw.RestoreDisplayMode
End Sub

Public Sub CreateSurfaceFromFile(Surface As DirectDrawSurface7, Surfdesc As DDSURFACEDESC2, Filename As String, width As Long, height As Long)
    On Error GoTo LostFile
    'loads a bitmap from a file and makes a pic from it
    Surfdesc.lFlags = DDSD_CAPS Or DDSD_HEIGHT Or DDSD_WIDTH
    Surfdesc.ddsCaps.lCaps = DDSCAPS_OFFSCREENPLAIN
    Surfdesc.lWidth = width
    Surfdesc.lHeight = height
    
    Set Surface = DX_Draw.CreateSurfaceFromFile(Filename, Surfdesc)
    Exit Sub
LostFile:
    MsgBox "File not found : " & Filename
End Sub



Public Sub InitDX(hwnd As Long)
    If InExMode Then Exit Sub
    
    On Error GoTo DontWork
    'create direct draw
    Set DX_Draw = DirectX.DirectDrawCreate("")
    'set fullscreen, exclusive
    If FullScreen = True Then
        DX_Draw.SetCooperativeLevel hwnd, DDSCL_FULLSCREEN Or DDSCL_ALLOWMODEX Or DDSCL_EXCLUSIVE
    Else
        DX_Draw.SetCooperativeLevel hwnd, DDSCL_NORMAL 'Or DDSCL_ALLOWMODEX  ' Or DDSCL_EXCLUSIVE
    End If
    InExMode = True
    Exit Sub
    
DontWork:
    MsgBox "Error - Cannot activate DirectX 7. Make sure you have it installed.", vbExclamation, "Error!"
    End
End Sub

'Sub StretchBlt(Pic As DirectDrawSurface7, x As Long, y As Long, width As Long, height As Long, DestPic As DirectDrawSurface7, DestX As Long, DestY As Long, DestWidth As Long, DestHeight As Long)
'    WaitTillOK
'    Dim Box As RECT
'    Box.Left = x
'    Box.Top = y
'    Box.Right = x + width
'    Box.Bottom = y + height
'
'    Dim DestBox As RECT
'    DestBox.Left = DestX
'    DestBox.Top = DestY
'    DestBox.Right = DestX + DestWidth
'    DestBox.Bottom = DestY + DestHeight
'
'    Pic.Blt DestBox, DestPic, Box, DDBLT_WAIT
'End Sub

'Sub BitBlt(Pic As DirectDrawSurface7, x As Integer, y As Integer, width As Integer, height As Integer, DestPic As DirectDrawSurface7, DestX As Integer, DestY As Integer)
'    WaitTillOK
'    Dim DestBox As RECT
'    DestBox.Left = DestX
'    DestBox.Top = DestY
'    DestBox.Right = DestX + DestWidth
'    DestBox.Bottom = DestY + DestHeight
'
'    Pic.BltFast x, y, DestPic, DestBox, DDBLTFAST_WAIT
'End Sub

Sub WaitTillOK()
    Dim bRestore As Boolean
    
    bRestore = False
    Do Until ExModeActive 'short way of saying "do until it returns true"
        DoEvents 'Lets windows do other things
        bRestore = True
    Loop
    
    ' if we lost and got back the surfaces, then restore them
    DoEvents
    If bRestore Then
        bRestore = False
        DX_Draw.RestoreAllSurfaces
        ModSurfaces.LoadAllPics ' must init the surfaces again if they we're lost. When this happens the first line of initsurfaces is important
    End If
End Sub

Function ExModeActive() As Boolean
     Dim TestCoopRes As Long 'holds the return value of the test.

     TestCoopRes = DX_Draw.TestCooperativeLevel 'Tells DDraw to do the test

     If (TestCoopRes = DD_OK) Then
         ExModeActive = True 'everything is fine
     Else
         ExModeActive = False 'this computer doesn't support this mode
     End If
 End Function
 
Public Sub EndDX(hwnd As Long)
    DX_Draw.RestoreDisplayMode 'added
    DX_Draw.SetCooperativeLevel hwnd, DDSCL_NORMAL
    InExMode = False
End Sub

Public Sub AddColorKey(Surface As DirectDrawSurface7, ColorKey As DDCOLORKEY, low As Long, high As Long)
    ColorKey.low = low
    ColorKey.high = high
    Surface.SetColorKey DDCKEY_SRCBLT, ColorKey
End Sub

Public Sub SetRect(Box As RECT, Left As Long, Top As Long, width As Long, height As Long)
    Box.Left = Left
    Box.Top = Top
    Box.Right = Left + width
    Box.Bottom = Top + height
End Sub

Public Sub ClearSurface(Surface As DirectDrawSurface7, width As Long, height As Long)
    Surface.SetForeColor vbBlack
    SetRect SrcRect, 0, 0, 1, 1
    SetRect DestRect, 0, 0, width, height
    Surface.DrawLine 0, 0, 1, 1
    Surface.Blt DestRect, Surface, SrcRect, DDBLT_WAIT
End Sub

